=======
History
=======

0.0.1 - 15/05/2013 - Some dirty code to get it works

0.0.2 - 02/06/2013 - Improve command line with argparse, organize and clean code, test with multiple and simple output : OK

0.0.3 - 06/10/2013 - Clean code,

0.1.1 - 13/03/2014 - First release on PyPI.

0.1.3 - 14/03/2014 - Add python3 compatibility